pkgname <- "mixlm"
source(file.path(R.home("share"), "R", "examples-header.R"))
options(warn = 1)
options(pager = "console")
library('mixlm')

base::assign(".oldSearch", base::search(), pos = 'CheckExEnv')
cleanEx()
nameEx("Anova")
### * Anova

flush(stderr()); flush(stdout())

### Name: Anova.lm
### Title: Analysis of variance with SS type II or III (including mixed
###   models).
### Aliases: Anova.lm Anova.II.lm Anova.III.lm ConjComp has.intercept
###   has.intercept.default has.intercept.matrix response response.default
###   responseName responseName.default relatives term.names
###   term.names.default Anova
### Keywords: ANOVA

### ** Examples

mixlm <- lm(y~x*r(z),
		    data = data.frame(y = rnorm(8),
							  x = factor(c(rep(1,4),rep(0,4))),
							  z = factor(rep(c(1,0),4))))
Anova(mixlm, type="III")



cleanEx()
nameEx("AnovaMix")
### * AnovaMix

flush(stderr()); flush(stdout())

### Name: AnovaMix
### Title: Mixed model least squares analysis of variance (mixed ANOVA).
### Aliases: AnovaMix
### Keywords: ANOVA

### ** Examples

mixlm <- lm(y~x*r(z),
			data = data.frame(y = rnorm(8),
							  x = factor(c(rep(1,4),rep(0,4))),
							  z = factor(rep(c(1,0),4))))
Anova(mixlm,type="III")



cleanEx()
nameEx("CIgrandMean")
### * CIgrandMean

flush(stderr()); flush(stdout())

### Name: CIgrandMean
### Title: Confidence interval for the grand mean of a linear model
### Aliases: CIgrandMean print.CIgm
### Keywords: Confidence interval Linear model

### ** Examples

dataset   <- data.frame(y=rnorm(8), x=factor(c(rep(1,4),rep(0,4))), z=factor(rep(c(1,0),4)))
mixlm <- lm(y~x*r(z), data = dataset)
CIgrandMean(mixlm)



cleanEx()
nameEx("PRESS")
### * PRESS

flush(stderr()); flush(stdout())

### Name: PRESS
### Title: Prediction fits
### Aliases: PRESS PRESS.res PRESS.pred R2pred RMSEP
### Keywords: Regression

### ** Examples

data <- data.frame(y = rnorm(8),
				   x = factor(c('a','a','a','a','b','b','b','b')),
				   z = factor(c('a','a','b','b','a','a','b','b')))
mod <- lm(y ~ x + z, data=data)
RMSEP(mod)
R2pred(mod)
PRESS(mod)
PRESS.res(mod)
PRESS.pred(mod)



cleanEx()
nameEx("anova.lm")
### * anova.lm

flush(stderr()); flush(stdout())

### Name: anova.lm
### Title: Analysis of variance (sequential SS)
### Aliases: anova.lm anova.lmlist anova
### Keywords: ANOVA

### ** Examples

mixlm <- lm(y~x*r(z),
			data = data.frame(y = rnorm(8),
							  x = factor(c(rep(1,4),rep(0,4))),
							  z = factor(rep(c(1,0),4))))
## Not run: 
##D anova(mixlm)
## End(Not run)



cleanEx()
nameEx("anova_reg")
### * anova_reg

flush(stderr()); flush(stdout())

### Name: anova_reg
### Title: Analysis of variance for regression.
### Aliases: anova_reg

### ** Examples

anova_reg(lm(y~x, data=data.frame(y=1:4,x=rnorm(4))))



cleanEx()
nameEx("best.subsets")
### * best.subsets

flush(stderr()); flush(stdout())

### Name: best.subsets
### Title: F-test based best subset selection.
### Aliases: best.subsets
### Keywords: regression

### ** Examples

data <- data.frame(y = rnorm(8),
				   x = factor(c('a','a','a','a','b','b','b','b')),
				   z = factor(c('a','a','b','b','a','a','b','b')))
mod <- lm(y ~ x + z, data=data)
best.subsets(mod)



cleanEx()
nameEx("confusion")
### * confusion

flush(stderr()); flush(stdout())

### Name: confusion
### Title: Confusion matrix.
### Aliases: confusion
### Keywords: Classification

### ** Examples

true <- c('a','a','b','b','c','c')
predicted <- c('a','c','b','b','a','c')
confusion(true, predicted)



cleanEx()
nameEx("forward")
### * forward

flush(stderr()); flush(stdout())

### Name: forward
### Title: F-test based model effect selection for linear models.
### Aliases: forward backward stepWise stepWiseBack
### Keywords: regression

### ** Examples

data <- data.frame(y = rnorm(8),
				   x = factor(c('a','a','a','a','b','b','b','b')),
				   z = factor(c('a','a','b','b','a','a','b','b')))
mod <- lm(y ~ x + z, data=data)
forward(mod)
backward(mod)
stepWise(mod)
stepWiseBack(mod)



cleanEx()
nameEx("fparse")
### * fparse

flush(stderr()); flush(stdout())

### Name: fparse
### Title: Effects of formulas.
### Aliases: fparse

### ** Examples

f <- formula(y~x*r(z))
fparse(f)



cleanEx()
nameEx("glm")
### * glm

flush(stderr()); flush(stdout())

### Name: glm
### Title: Fitting Generalized Linear Models
### Aliases: glm print.glm
### Keywords: models regression

### ** Examples

## Dobson (1990) Page 93: Randomized Controlled Trial :
counts <- c(18,17,15,20,10,20,25,13,12)
outcome <- gl(3,1,9)
treatment <- gl(3,3)
print(d.AD <- data.frame(treatment, outcome, counts))
glm.D93 <- glm(counts ~ outcome + treatment, family=poisson())
anova(glm.D93)

# A Gamma example, from McCullagh & Nelder (1989, pp. 300-2)
clotting <- data.frame(
    u = c(5,10,15,20,30,40,60,80,100),
    lot1 = c(118,58,42,35,27,25,21,19,18),
    lot2 = c(69,35,26,21,18,16,13,12,12))
summary(glm(lot1 ~ log(u), data=clotting, family=Gamma))
summary(glm(lot2 ~ log(u), data=clotting, family=Gamma))

# Mixed model example
dataset   <- data.frame(y=rnorm(8), x=factor(c(rep(1,4),rep(0,4))), z=factor(rep(c(1,0),4)))
GLM       <- glm(y  ~ x+r(z), family=gaussian(identity), data=dataset)
summary(GLM)
logLik(GLM)
## Not run: 
##D Anova(GLM,type=3)
## End(Not run)

## Not run: 
##D ## for an example of the use of a terms object as a formula
##D demo(glm.vr)
## End(Not run)


cleanEx()
nameEx("is.balanced")
### * is.balanced

flush(stderr()); flush(stdout())

### Name: is.balanced
### Title: Balance cheking of models.
### Aliases: is.balanced

### ** Examples

mixlm <- lm(y~x*r(z),
		    data = data.frame(y = rnorm(8),
							  x = factor(c(rep(1,4),rep(0,4))),
							  z = factor(rep(c(1,0),4))))
is.balanced(mixlm)



cleanEx()
nameEx("lm")
### * lm

flush(stderr()); flush(stdout())

### Name: lm
### Title: Fitting Linear Models
### Aliases: lm summary.lm lmer qr.lm mixlm print.lm random.worker
### Keywords: regression

### ** Examples

require(graphics)

## Annette Dobson (1990) "An Introduction to Generalized Linear Models".
## Page 9: Plant Weight Data.
ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
group <- gl(2,10,20, labels=c("Ctl","Trt"))
weight <- c(ctl, trt)
lm.D9 <- lm(weight ~ group)
lm.D90 <- lm(weight ~ group - 1) # omitting intercept
opar <- par(mfrow = c(2,2), oma = c(0, 0, 1.1, 0))
plot(lm.D9, las = 1)      # Residuals, Fitted, ...
par(opar)

# Linear mixed model
dataset   <- data.frame(y=rnorm(8), x=factor(c(rep(1,4),rep(0,4))), z=factor(rep(c(1,0),4)))
mixlm <- lm(y~x*r(z), data = dataset)
Anova(mixlm,type="III")

### less simple examples in "See Also" above



graphics::par(get("par.postscript", pos = 'CheckExEnv'))
cleanEx()
nameEx("plotprops")
### * plotprops

flush(stderr()); flush(stdout())

### Name: plotprops
### Title: Property plots for relevant component analysis
### Aliases: plotprops
### Keywords: Regression Classification

### ** Examples

X <- matrix(rnorm(100),20,5)
Y <- matrix(rnorm(20),20,1)
plotprops(Y, X, doscaleX = FALSE, docenterX = TRUE, 5)



cleanEx()
nameEx("print.AnovaMix")
### * print.AnovaMix

flush(stderr()); flush(stdout())

### Name: print.AnovaMix
### Title: Print method for objects of class(AnovaMix)
### Aliases: print.AnovaMix print
### Keywords: ANOVA

### ** Examples

mixlm <- lm(y~x*r(z),
			data = data.frame(y = rnorm(8),
							  x = factor(c(rep(1,4),rep(0,4))),
							  z = factor(rep(c(1,0),4))))
Anova(mixlm,type="III")



cleanEx()
nameEx("print.summary.lm")
### * print.summary.lm

flush(stderr()); flush(stdout())

### Name: print.summary.lm
### Title: Summarizing Linear Model Fits
### Aliases: print.summary.lm
### Keywords: regression models

### ** Examples

ctl <- c(4.17,5.58,5.18,6.11,4.50,4.61,5.17,4.53,5.33,5.14)
trt <- c(4.81,4.17,4.41,3.59,5.87,3.83,6.03,4.89,4.32,4.69)
group <- gl(2,10,20, labels=c("Ctl","Trt"))
weight <- c(ctl, trt)
sld90 <- summary(lm.D90 <- lm(weight ~ group -1))# omitting intercept
sld90



cleanEx()
nameEx("prop.test.ordinary")
### * prop.test.ordinary

flush(stderr()); flush(stdout())

### Name: prop.test.ordinary
### Title: Test of Equal or Given Proportions in text book version
### Aliases: prop.test.ordinary
### Keywords: htest

### ** Examples

heads <- rbinom(1, size=100, prob = .5)
prop.test(heads, 100)          # continuity correction TRUE by default
prop.test(heads, 100, correct = FALSE)

## Data from Fleiss (1981), p. 139.
## H0: The null hypothesis is that the four populations from which
##     the patients were drawn have the same true proportion of smokers.
## A:  The alternative is that this proportion is different in at
##     least one of the populations.

smokers  <- c( 83, 90, 129, 70 )
patients <- c( 86, 93, 136, 82 )
prop.test.ordinary(smokers, patients)



cleanEx()
nameEx("rparse")
### * rparse

flush(stderr()); flush(stdout())

### Name: rparse
### Title: Removes function r() from formulas.
### Aliases: rparse

### ** Examples

f <- formula(y~x*r(z))
rparse(f)



cleanEx()
nameEx("simple.glht")
### * simple.glht

flush(stderr()); flush(stdout())

### Name: simple.glht
### Title: Pairwise comparison with multiple testing compensation.
### Aliases: simple.glht print.simple.glht
### Keywords: models design

### ** Examples

require(graphics)

summary(fm1 <- lm(breaks ~ wool + tension, data = warpbreaks))
simple.glht(fm1, "tension")
plot(simple.glht(fm1, "tension"))
cld(simple.glht(fm1, "tension"))



cleanEx()
nameEx("spearson")
### * spearson

flush(stderr()); flush(stdout())

### Name: spearson
### Title: Standardized Pearson residuals
### Aliases: spearson
### Keywords: Regression

### ** Examples

data <- data.frame(y = rnorm(8),
				   x = factor(c('a','a','a','a','b','b','b','b')),
				   z = factor(c('a','a','b','b','a','a','b','b')))
mod <- lm(y ~ x + z, data=data)
spearson(mod)



cleanEx()
nameEx("t_test")
### * t_test

flush(stderr()); flush(stdout())

### Name: t_test
### Title: Text book versions of t-tests and z-tests.
### Aliases: t_test t_test.formula t_test.default t_test_sum z_test
###   z_test.formula z_test.default z_test_sum
### Keywords: htest

### ** Examples


t.test(1:10,y=c(7:20))      # P = .00001855
t.test(1:10,y=c(7:20, 200)) # P = .1245    -- NOT significant anymore

## Classical example: Student's sleep data
plot(extra ~ group, data = sleep)
## Traditional interface
with(sleep, t.test(extra[group == 1], extra[group == 2]))
## Formula interface
t_test(extra ~ group, data = sleep)



cleanEx()
nameEx("tally")
### * tally

flush(stderr()); flush(stdout())

### Name: tally
### Title: Tally of discrete numbers
### Aliases: tally
### Keywords: Numbers

### ** Examples

tally(c(1,5,1,3,2,5,6,2,2,1,4,3,6))



### * <FOOTER>
###
options(digits = 7L)
base::cat("Time elapsed: ", proc.time() - base::get("ptime", pos = 'CheckExEnv'),"\n")
grDevices::dev.off()
###
### Local variables: ***
### mode: outline-minor ***
### outline-regexp: "\\(> \\)?### [*]+" ***
### End: ***
quit('no')
